@@ -6,7 +6,7 @@
  *  these oopses for good, so we run those stupid tests... */
 
 /*
- *  GiNaC Copyright (C) 1999-2010 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -467,6 +467,50 @@ static unsigned exam_paranoia17()
 	return test_cycl.get_free_indices().size();
 }
 
+// Bug in add::eval() could result in numeric terms not being collected into
+// the overall coefficient. Fixed on Sep 22, 2010
+static unsigned exam_paranoia18()
+{
+	ex sqrt2 = sqrt(ex(2));
+	ex e = 1+2*(sqrt2+1)*(sqrt2-1);
+	if ( e.real_part() != 3 ) {
+		clog << "real_part(1+2*(sqrt(2)+1)*(sqrt(2)-1)) failed to evaluate to 3\n";
+		return 1;
+	}
+	return 0;
+}
+
+// Bug in mul::conjugate when factors are evaluated at branch cuts, reported as
+// Sage bug #10964.
+static unsigned exam_paranoia19()
+{
+	symbol a("a");
+	ex e = conjugate(a*sqrt(ex(-2))*sqrt(ex(-3)));
+	ex c = a*conjugate(sqrt(ex(-2)))*conjugate(sqrt(ex(-3)));
+	if (!subs(e-c, a==42).is_zero()) {
+		clog << "subs(a*conjugate(sqrt(-2))*conjugate(sqrt(-3))-conjugate(a*sqrt(-2)*sqrt(-3)),a==42) failed to evaluate to 0\n";
+		return 1;
+	}
+	return 0;
+}
+
+// Bug in expairseq::is_polynomial (fixed 2011-05-20).
+static unsigned exam_paranoia20()
+{
+	unsigned result = 0;
+	symbol x("x");
+	ex e1 = sqrt(x*x+1)*sqrt(x+1);
+	if (e1.is_polynomial(x)) {
+		clog << "sqrt(x*x+1)*sqrt(x+1) is wrongly reported to be a polynomial in x\n";
+		++result;
+	}
+	ex e2 = sqrt(Pi)*x;
+	if (!e2.is_polynomial(x)) {
+		clog << "sqrt(Pi)*x is wrongly reported to be no polynomial in x\n";
+		++result;
+	}
+	return result;
+}
 
 unsigned exam_paranoia()
 {
@@ -491,6 +535,9 @@ unsigned exam_paranoia()
 	result += exam_paranoia15();  cout << '.' << flush;
 	result += exam_paranoia16();  cout << '.' << flush;
 	result += exam_paranoia17();  cout << '.' << flush;
+	result += exam_paranoia18();  cout << '.' << flush;
+	result += exam_paranoia19();  cout << '.' << flush;
+	result += exam_paranoia20();  cout << '.' << flush;
 	
 	return result;
 }
