@@ -3,7 +3,7 @@
  *  Interface to GiNaC's sums of expressions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_ADD_H__
-#define __GINAC_ADD_H__
+#ifndef GINAC_ADD_H
+#define GINAC_ADD_H
 
 #include "expairseq.h"
 
@@ -47,6 +47,7 @@ public:
 public:
 	unsigned precedence() const {return 40;}
 	bool info(unsigned inf) const;
+	bool is_polynomial(const ex & var) const;
 	int degree(const ex & s) const;
 	int ldegree(const ex & s) const;
 	ex coeff(const ex & s, int n=1) const;
@@ -65,7 +66,7 @@ public:
 protected:
 	ex derivative(const symbol & s) const;
 	unsigned return_type() const;
-	tinfo_t return_type_tinfo() const;
+	return_type_t return_type_tinfo() const;
 	ex thisexpairseq(const epvector & v, const ex & oc, bool do_index_renaming = false) const;
 	ex thisexpairseq(std::auto_ptr<epvector> vp, const ex & oc, bool do_index_renaming = false) const;
 	expair split_ex_to_pair(const ex & e) const;
@@ -84,7 +85,8 @@ protected:
 	void do_print_csrc(const print_csrc & c, unsigned level) const;
 	void do_print_python_repr(const print_python_repr & c, unsigned level) const;
 };
+GINAC_DECLARE_UNARCHIVER(add);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_ADD_H__
+#endif // ndef GINAC_ADD_H
