@@ -3,7 +3,7 @@
  *  Interface to sequences of expression pairs. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,18 +20,18 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_EXPAIRSEQ_H__
-#define __GINAC_EXPAIRSEQ_H__
-
-#include <vector>
-#include <list>
-#include <memory>
-// CINT needs <algorithm> to work properly with <vector> and <list>
-#include <algorithm>
+#ifndef GINAC_EXPAIRSEQ_H
+#define GINAC_EXPAIRSEQ_H
 
 #include "expair.h"
 #include "indexed.h"
 
+// CINT needs <algorithm> to work properly with <vector> and <list>
+#include <algorithm>
+#include <list>
+#include <memory>
+#include <vector>
+
 namespace GiNaC {
 
 /** Using hash tables can potentially enhance the asymptotic behaviour of
@@ -84,10 +84,12 @@ public:
 	ex eval(int level=0) const;
 	ex to_rational(exmap & repl) const;
 	ex to_polynomial(exmap & repl) const;
-	bool match(const ex & pattern, lst & repl_lst) const;
+	bool match(const ex & pattern, exmap& repl_lst) const;
 	ex subs(const exmap & m, unsigned options = 0) const;
 	ex conjugate() const;
-	bool is_polynomial(const ex & var) const;
+
+	void archive(archive_node& n) const;
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	bool is_equal_same_type(const basic & other) const;
 	unsigned return_type() const;
@@ -105,9 +107,9 @@ protected:
 	                       unsigned upper_precedence) const;
 	virtual expair split_ex_to_pair(const ex & e) const;
 	virtual expair combine_ex_with_coeff_to_pair(const ex & e,
-												 const ex & c) const;
+	                                             const ex & c) const;
 	virtual expair combine_pair_with_coeff_to_pair(const expair & p,
-												   const ex & c) const;
+	                                               const ex & c) const;
 	virtual ex recombine_pair_to_ex(const expair & p) const;
 	virtual bool expair_needs_further_processing(epp it);
 	virtual ex default_overall_coeff() const;
@@ -228,4 +230,4 @@ class make_flat_inserter
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_EXPAIRSEQ_H__
+#endif // ndef GINAC_EXPAIRSEQ_H
