@@ -3,7 +3,7 @@
  *  Implementation of GiNaC's exprseq. */
 
 /*
- *  GiNaC Copyright (C) 1999-2010 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,4 +37,10 @@ template <> bool exprseq::info(unsigned inf) const
 		return inherited::info(inf);
 }
 
+#ifdef _MSC_VER
+  // MSVC does not include exprseq::info() in the library without
+  // defining some kind of dummy function here
+  basic* dummy_func(void) { return new exprseq(); }
+#endif
+
 } // namespace GiNaC
