@@ -3,7 +3,7 @@
  *  Definition of GiNaC's exprseq. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,23 +20,20 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_EXPRSEQ_H__
-#define __GINAC_EXPRSEQ_H__
-
-#include <vector>
+#ifndef GINAC_EXPRSEQ_H
+#define GINAC_EXPRSEQ_H
 
 #include "container.h"
 
+#include <vector>
+
 namespace GiNaC {
 
 typedef container<std::vector> exprseq;
 
-/** Specialization of container::get_tinfo() for exprseq. */
-template<> inline tinfo_t exprseq::get_tinfo() { return &exprseq::tinfo_static; }
-
 // defined in exprseq.cpp
 template<> bool exprseq::info(unsigned inf) const;
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_EXPRSEQ_H__
+#endif // ndef GINAC_EXPRSEQ_H
