@@ -3,7 +3,7 @@
  *  Interface to abstract derivatives of functions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,15 +20,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_FDERIVATIVE_H__
-#define __GINAC_FDERIVATIVE_H__
-
-#include <set>
+#ifndef GINAC_FDERIVATIVE_H
+#define GINAC_FDERIVATIVE_H
 
 #include "function.h"
 
-namespace GiNaC {
+#include <set>
 
+namespace GiNaC {
 
 typedef std::multiset<unsigned> paramset;
 
@@ -66,6 +65,8 @@ public:
 	ex series(const relational & r, int order, unsigned options = 0) const;
 	ex thiscontainer(const exvector & v) const;
 	ex thiscontainer(std::auto_ptr<exvector> vp) const;
+	void archive(archive_node& n) const;
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	ex derivative(const symbol & s) const;
 	bool is_equal_same_type(const basic & other) const;
@@ -81,7 +82,8 @@ protected:
 protected:
 	paramset parameter_set; /**< Set of parameter numbers with respect to which to take the derivative */
 };
+GINAC_DECLARE_UNARCHIVER(fderivative); 
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_DERIVATIVE_H__
+#endif // ndef GINAC_DERIVATIVE_H
