@@ -3,7 +3,7 @@
  *  Interface to GiNaC's products of expressions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_MUL_H__
-#define __GINAC_MUL_H__
+#ifndef GINAC_MUL_H
+#define GINAC_MUL_H
 
 #include "expairseq.h"
 
@@ -49,6 +49,7 @@ public:
 public:
 	unsigned precedence() const {return 50;}
 	bool info(unsigned inf) const;
+	bool is_polynomial(const ex & var) const;
 	int degree(const ex & s) const;
 	int ldegree(const ex & s) const;
 	ex coeff(const ex & s, int n = 1) const;
@@ -64,11 +65,12 @@ public:
 	ex smod(const numeric &xi) const;
 	numeric max_coefficient() const;
 	exvector get_free_indices() const;
+	ex conjugate() const;
 protected:
 	ex derivative(const symbol & s) const;
 	ex eval_ncmul(const exvector & v) const;
 	unsigned return_type() const;
-	tinfo_t return_type_tinfo() const;
+	return_type_t return_type_tinfo() const;
 	ex thisexpairseq(const epvector & v, const ex & oc, bool do_index_renaming = false) const;
 	ex thisexpairseq(std::auto_ptr<epvector> vp, const ex & oc, bool do_index_renaming = false) const;
 	expair split_ex_to_pair(const ex & e) const;
@@ -98,7 +100,8 @@ protected:
 	static bool can_be_further_expanded(const ex & e);
 	std::auto_ptr<epvector> expandchildren(unsigned options) const;
 };
+GINAC_DECLARE_UNARCHIVER(mul);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_MUL_H__
+#endif // ndef GINAC_MUL_H
