@@ -3,7 +3,7 @@
  *  Interface to GiNaC's non-commutative products of expressions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2005 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,11 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_NCMUL_H__
-#define __GINAC_NCMUL_H__
+#ifndef GINAC_NCMUL_H
+#define GINAC_NCMUL_H
 
 #include "exprseq.h"
+#include "archive.h"
 
 namespace GiNaC {
 
@@ -65,11 +66,13 @@ public:
 	ex thiscontainer(const exvector & v) const;
 	ex thiscontainer(std::auto_ptr<exvector> vp) const;
 	ex conjugate() const;
+	ex real_part() const;
+	ex imag_part() const;
 
 protected:
 	ex derivative(const symbol & s) const;
 	unsigned return_type() const;
-	unsigned return_type_tinfo() const;
+	return_type_t return_type_tinfo() const;
 	
 	// new virtual functions which can be overridden by derived classes
 	// none
@@ -84,20 +87,13 @@ protected:
 public:
 	const exvector & get_factors() const;
 };
+GINAC_DECLARE_UNARCHIVER(ncmul);
 
 // friend funtions 
 
 ex reeval_ncmul(const exvector & v);
 ex hold_ncmul(const exvector & v);
 
-// utility functions
-
-/** Specialization of is_exactly_a<ncmul>(obj) for ncmul objects. */
-template<> inline bool is_exactly_a<ncmul>(const basic & obj)
-{
-	return obj.tinfo()==TINFO_ncmul;
-}
-
 } // namespace GiNaC
 
-#endif // ndef __GINAC_NCMUL_H__
+#endif // ndef GINAC_NCMUL_H
