@@ -3,7 +3,7 @@
  *  Interface to GiNaC's symmetry definitions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,16 +20,16 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_SYMMETRY_H__
-#define __GINAC_SYMMETRY_H__
+#ifndef GINAC_SYMMETRY_H
+#define GINAC_SYMMETRY_H
+
+#include "ex.h"
+#include "archive.h"
 
 #include <set>
 
-#include "ex.h"
-
 namespace GiNaC {
 
-
 class sy_is_less;
 class sy_swap;
 
@@ -80,9 +80,15 @@ public:
 
 	/** Check whether this node actually represents any kind of symmetry. */
 	bool has_symmetry() const {return type != none || !children.empty(); }
+	/** Check whether this node involves anything non symmetric. */
+	bool has_nonsymmetric() const;
 	/** Check whether this node involves a cyclic symmetry. */
 	bool has_cyclic() const;
 
+	/** Save (a.k.a. serialize) object into archive. */
+	void archive(archive_node& n) const;
+	/** Read (a.k.a. deserialize) object from archive. */
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	void do_print(const print_context & c, unsigned level) const;
 	void do_print_tree(const print_tree & c, unsigned level) const;
@@ -99,6 +105,7 @@ private:
 	/** Vector of child nodes. */
 	exvector children;
 };
+GINAC_DECLARE_UNARCHIVER(symmetry); 
 
 
 // global functions
@@ -173,4 +180,4 @@ inline ex symmetrize_cyclic(const ex & e, const exvector & v)
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_SYMMETRY_H__
+#endif // ndef GINAC_SYMMETRY_H
