@@ -3,7 +3,7 @@
  *  Interface to GiNaC's special tensors. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,14 +20,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_TENSOR_H__
-#define __GINAC_TENSOR_H__
+#ifndef GINAC_TENSOR_H
+#define GINAC_TENSOR_H
 
 #include "ex.h"
+#include "archive.h"
 
 namespace GiNaC {
 
-
 /** This class holds one of GiNaC's predefined special tensors such as the
  *  delta and the metric tensors. They are represented without indices.
  *  To attach indices to them, wrap them in an object of class indexed. */
@@ -35,10 +35,6 @@ class tensor : public basic
 {
 	GINAC_DECLARE_REGISTERED_CLASS(tensor, basic)
 
-	// other constructors
-protected:
-	tensor(unsigned ti) : inherited(ti) {}
-
 	// functions overriding virtual functions from base classes
 protected:
 	unsigned return_type() const { return return_types::noncommutative_composite; }
@@ -60,14 +56,17 @@ class tensdelta : public tensor
 
 	// functions overriding virtual functions from base classes
 public:
+	bool info(unsigned inf) const;
 	ex eval_indexed(const basic & i) const;
 	bool contract_with(exvector::iterator self, exvector::iterator other, exvector & v) const;
 
 	// non-virtual functions in this class
 protected:
+	unsigned return_type() const { return return_types::commutative; }
 	void do_print(const print_context & c, unsigned level) const;
 	void do_print_latex(const print_latex & c, unsigned level) const;
 };
+GINAC_DECLARE_UNARCHIVER(tensdelta);
 
 
 /** This class represents a general metric tensor which can be used to
@@ -79,13 +78,16 @@ class tensmetric : public tensor
 
 	// functions overriding virtual functions from base classes
 public:
+	bool info(unsigned inf) const;
 	ex eval_indexed(const basic & i) const;
 	bool contract_with(exvector::iterator self, exvector::iterator other, exvector & v) const;
 
 	// non-virtual functions in this class
 protected:
+	unsigned return_type() const { return return_types::commutative; }
 	void do_print(const print_context & c, unsigned level) const;
 };
+GINAC_DECLARE_UNARCHIVER(tensmetric);
 
 
 /** This class represents a Minkowski metric tensor. It has all the
@@ -102,10 +104,16 @@ public:
 
 	// functions overriding virtual functions from base classes
 public:
+	bool info(unsigned inf) const;
 	ex eval_indexed(const basic & i) const;
 
+	/** Save (a.k.a. serialize) object into archive. */
+	void archive(archive_node& n) const;
+	/** Read (a.k.a. deserialize) object from archive. */
+	void read_archive(const archive_node& n, lst& syms);
 	// non-virtual functions in this class
 protected:
+	unsigned return_type() const { return return_types::commutative; }
 	void do_print(const print_context & c, unsigned level) const;
 	void do_print_latex(const print_latex & c, unsigned level) const;
 
@@ -113,6 +121,7 @@ protected:
 private:
 	bool pos_sig; /**< If true, the metric is diag(-1,1,1...). Otherwise it is diag(1,-1,-1,...). */
 };
+GINAC_DECLARE_UNARCHIVER(minkmetric); 
 
 
 /** This class represents an antisymmetric spinor metric tensor which
@@ -125,14 +134,15 @@ class spinmetric : public tensmetric
 
 	// functions overriding virtual functions from base classes
 public:
+	bool info(unsigned inf) const;
 	ex eval_indexed(const basic & i) const;
 	bool contract_with(exvector::iterator self, exvector::iterator other, exvector & v) const;
 
-	// non-virtual functions in this class
 protected:
 	void do_print(const print_context & c, unsigned level) const;
 	void do_print_latex(const print_latex & c, unsigned level) const;
 };
+GINAC_DECLARE_UNARCHIVER(spinmetric);
 
 
 /** This class represents the totally antisymmetric epsilon tensor. If
@@ -148,11 +158,17 @@ public:
 
 	// functions overriding virtual functions from base classes
 public:
+	bool info(unsigned inf) const;
 	ex eval_indexed(const basic & i) const;
 	bool contract_with(exvector::iterator self, exvector::iterator other, exvector & v) const;
 
+	/** Save (a.k.a. serialize) object into archive. */
+	void archive(archive_node& n) const;
+	/** Read (a.k.a. deserialize) object from archive. */
+	void read_archive(const archive_node& n, lst& syms);
 	// non-virtual functions in this class
 protected:
+	unsigned return_type() const { return return_types::commutative; }
 	void do_print(const print_context & c, unsigned level) const;
 	void do_print_latex(const print_latex & c, unsigned level) const;
 
@@ -161,6 +177,7 @@ private:
 	bool minkowski; /**< If true, tensor is in Minkowski-type space. Otherwise it is in a Euclidean space. */
 	bool pos_sig;   /**< If true, the metric is assumed to be diag(-1,1,1...). Otherwise it is diag(1,-1,-1,...). This is only relevant if minkowski = true. */
 };
+GINAC_DECLARE_UNARCHIVER(tensepsilon); 
 
 
 // utility functions
@@ -234,4 +251,4 @@ ex lorentz_eps(const ex & i1, const ex & i2, const ex & i3, const ex & i4, bool
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_TENSOR_H__
+#endif // ndef GINAC_TENSOR_H
